==> pc2m-0.9.10.zip: pc2m-0.9.10/Setup.inc.php <==
<?php

/* -------------------------------------------------------------------------
	!!!This file must be in EUC-JP!!!

	
	for PC2M Web Content Converter for Mobile Clients
	Copyright (C) 2005-2006 ucb@rcdtokyo.com
	http://www.rcdtokyo.com/pc2m/note/
------------------------------------------------------------------------- */

/* -------------------------------------------------------------------------
	̤Υڡȥ
------------------------------------------------------------------------- */

define('SETUP_TITLE', '');

/* -------------------------------------------------------------------------
	åܥǥ

	åܥǥϡHTMLʸreturnǵҤޤ
	ʲƤϡɽݤˤȾѤѴԤޤʳ
	ϰڹԤޤ󡣤ʤüбƤ뤹٤ƤΥ
	ʤѤǤޤ
------------------------------------------------------------------------- */

ob_start();

	echo '<form action="'.basename($_SERVER['SCRIPT_NAME']).'">'.
		((isset($_SESSION) and $local_args['d'] != null and !ENABLE_SESSION_COOKIE)?
			'<input type="hidden" name="'.KEY_PREFIX.'d" value="'.$local_args['d'].'">': null);

	// å奵ץ
	// üΥå奵7.5KBʲʤɽ
	if ($client->getCacheSize() > 7500) {
		echo '<p><label for="'.KEY_PREFIX.'c">å奵</label><br>';
		echo '<select name="'.KEY_PREFIX.'c">';
		echo '<option value=""'.(!$local_args['c']? ' selected': null).'>ư';
		echo '<option value="5"'.(($local_args['c'] == '5')? ' selected': null).'>5KB';
		if ($client->cache_size > 10000) {
			echo '<option value="10"'.(($local_args['c'] == '10')? ' selected': null).'>10KB';
			if ($client->cache_size > 20000) {
				echo '<option value="20"'.(($local_args['c'] == '20')? ' selected': null).'>20KB';
			}
		}

		// üΥå奵CACHESIZE_THRESHOLDĶƤ
		// üΥå奵κ͡KBñ̤üڤΤơˤɽ
		if (defined('CACHESIZE_THRESHOLD') and $client->cache_size > CACHESIZE_THRESHOLD) {
			$i = floor($client->cache_size /1000);
			echo '<option value="'.$i.'"'.($local_args['c'] == $i ? ' selected' : null).'>'.$i.'KB';
		}
		echo '</select>';
	}

	// ƥȤȲƱɽ饸ܥ
	if (defined("IMAGE_CONVERTER") and IMAGE_CONVERTER) {
		echo '<p><label for="'.KEY_PREFIX.'v">ƥȤȲƱɽ</label><br>
			<input type="radio" name="'.KEY_PREFIX.'v" value="0"'.
			(empty($local_args['v'])? ' checked': null).'>ƥȤΤɽ<br>
			<input type="radio" name="'.KEY_PREFIX.'v" value="1"'.
			(($local_args['v'] == 1)? ' checked': null).'>ɽ(Ѵ)<br>
			<input type="radio" name="'.KEY_PREFIX.'v" value="2"'.
			(($local_args['v'] == 2)? ' checked': null).'>ɽ(Ѵ)
			<p>ѴפϡְѴפǲɽʤˡɽ٤ʤޤ';
	}

	// 
	// ǿɽ򤬤ʤж
	echo '<p><label for="'.KEY_PREFIX.'u"></label><br>
		<input type="text" name="'.KEY_PREFIX.'u" size="8" value="';
	if (isset($_SESSION['history'])) {
		$array = sortMultiArray($_SESSION['history'], 0);
		foreach ($array as $key => $value) {
			echo ($value[4] == 'post')? $key: $value[1];
			break;
		}
	}
	echo '" istyle="3"><input type="submit" value=""></form>
		<p><a href="'.$script_self.'_ucb_a=l">å</a>()';

$_output_buffer = ob_get_contents();
ob_end_clean();
return $_output_buffer;

?>

==> pc2m-0.9.11.zip: pc2m-0.9.11/Setup.inc.php <==
<?php

/* -------------------------------------------------------------------------
	!!!This file must be in EUC-JP!!!

	
	for PC2M Web Content Converter for Mobile Clients
	Copyright (C) 2005-2006 ucb@rcdtokyo.com
	http://www.rcdtokyo.com/pc2m/note/
------------------------------------------------------------------------- */

/* -------------------------------------------------------------------------
	̤Υڡȥ
------------------------------------------------------------------------- */

define('SETUP_TITLE', '');

/* -------------------------------------------------------------------------
	åܥǥ

	åܥǥϡHTMLʸreturnǵҤޤ
	ʲƤϡɽݤˤȾѤѴԤޤʳ
	ϰڹԤޤ󡣤ʤüбƤ뤹٤ƤΥ
	ʤѤǤޤ
------------------------------------------------------------------------- */

ob_start();

	echo '<form action="'.basename($_SERVER['SCRIPT_NAME']).'">'.
		((isset($_SESSION) and $local_args['d'] != null and !ENABLE_SESSION_COOKIE)?
			'<input type="hidden" name="'.KEY_PREFIX.'d" value="'.$local_args['d'].'">': null);

	// å奵ץ
	// üΥå奵7.5KBʲʤɽ
	if ($client->getCacheSize() > 7500) {
		echo '<p><label for="'.KEY_PREFIX.'c">å奵</label><br>';
		echo '<select name="'.KEY_PREFIX.'c">';
		echo '<option value=""'.(!$local_args['c']? ' selected': null).'>ư';
		echo '<option value="5"'.(($local_args['c'] == '5')? ' selected': null).'>5KB';
		if ($client->cache_size > 10000) {
			echo '<option value="10"'.(($local_args['c'] == '10')? ' selected': null).'>10KB';
			if ($client->cache_size > 20000) {
				echo '<option value="20"'.(($local_args['c'] == '20')? ' selected': null).'>20KB';
			}
		}

		// üΥå奵CACHESIZE_THRESHOLDĶƤ
		// üΥå奵κ͡KBñ̤üڤΤơˤɽ
		if (defined('CACHESIZE_THRESHOLD') and $client->cache_size > CACHESIZE_THRESHOLD) {
			$i = floor($client->cache_size /1000);
			echo '<option value="'.$i.'"'.($local_args['c'] == $i ? ' selected' : null).'>'.$i.'KB';
		}
		echo '</select>';
	}

	// ƥȤȲƱɽ饸ܥ
	if (defined("IMAGE_CONVERTER") and IMAGE_CONVERTER) {
		echo '<p><label for="'.KEY_PREFIX.'v">ƥȤȲƱɽ</label><br>
			<input type="radio" name="'.KEY_PREFIX.'v" value="0"'.
			(empty($local_args['v'])? ' checked': null).'>ƥȤΤɽ<br>
			<input type="radio" name="'.KEY_PREFIX.'v" value="1"'.
			(($local_args['v'] == 1)? ' checked': null).'>ɽ(Ѵ)<br>
			<input type="radio" name="'.KEY_PREFIX.'v" value="2"'.
			(($local_args['v'] == 2)? ' checked': null).'>ɽ(Ѵ)
			<p>ѴפϡְѴפǲɽʤˡɽ٤ʤޤ';
	}

	// ݻ饸ܥ
	echo '<p><label for="'.KEY_PREFIX.'l">ݻ</label><br>
		<input type="radio" name="'.KEY_PREFIX.'l" value="0"'.
		(empty($local_args['l'])? ' checked': null).'>ʤ<br>
		<input type="radio" name="'.KEY_PREFIX.'l" value="1"'.
		(($local_args['l'] == 1)? ' checked': null).'>
		<p>֤פǤFONTBʤɤBODYοĤޤ(TABLECSSоݳ)1̤ɽʸϸޤ';

	// 
	// ǿɽ򤬤ʤж
	echo '<p><label for="'.KEY_PREFIX.'u">URL</label><br>
		<input type="text" name="'.KEY_PREFIX.'u" size="8" value="';
	if (isset($_SESSION['history'])) {
		$array = sortMultiArray($_SESSION['history'], 0);
		foreach ($array as $key => $value) {
			echo ($value[4] == 'post')? $key: $value[1];
			break;
		}
	}
	echo '" istyle="3"><input type="submit" value=""></p>
		<p><label for="'.KEY_PREFIX.'s">ɽϰ(ڡ⸡)</label><br>
		<input type="text" name="'.KEY_PREFIX.'s" size="8"></form>
		<hr>
		<p><a href="'.$script_self.'_ucb_a=l">å</a>()';

$_output_buffer = ob_get_contents();
ob_end_clean();
return $_output_buffer;

?>
